# python 打包发布
参照文章： https://blog.csdn.net/Good_Luck_Kevin2018/article/details/80737728

## General

### 发布步骤
1. 新建 setup.py文件
2. 编译 python setup.py build 
3. 打包 python setup.py sdist
4. 安装 python setup.py install
5. python setup.py sdist bdist_wheel
6. python -m twine upload dist/*
